@@ -122,7 +122,12 @@ class PayInvoiceUsingTransactionStart(BaseCreditCardViewMixin, ModelView):
     transaction_type = fields.Function(
         fields.Char("Transaction Type"), "on_change_with_transaction_type"
     )
-    party = fields.Many2One('party.party', 'Party', readonly=True)
+    party = fields.Many2One('party.party', 'Party',
+        readonly=True,
+        context={
+            'company': Eval('company', -1),
+            },
+        depends=['user'])
     gateway = fields.Many2One(
         'payment_gateway.gateway', 'Gateway', required=True,
         domain=[('users', '=', Eval('user'))],
@@ -185,10 +190,14 @@ class PayInvoiceUsingTransactionStart(BaseCreditCardViewMixin, ModelView):
         'payment_gateway.transaction', "Transaction", domain=[
             ('party', '=', Eval('party')),
             ('gateway', '=', Eval('gateway')),
-        ], states={
+        ],
+        context={
+            'company': Eval('company', -1),
+            },
+        states={
             'required': Eval('transaction_type') == 'refund',
             'invisible': Eval('transaction_type') != 'refund'
-        }, depends=['party', 'transaction_type', 'gateway']
+        }, depends=['company', 'party', 'transaction_type', 'gateway']
     )
 
     @classmethod
