@@ -1,13 +1,15 @@
 # The COPYRIGHT file at the top level of this repository contains
 # the full copyright notices and license terms.
 import unittest
+
 from decimal import Decimal
 
 from dateutil.relativedelta import relativedelta
+
 from trytond.exceptions import UserError
 from trytond.modules.account.tests import create_chart, get_fiscalyear
 from trytond.modules.account_invoice.tests import set_invoice_sequences
-from trytond.modules.company.tests import create_company, set_company
+from trytond.modules.company.tests import create_company, set_company, CompanyTestMixin
 from trytond.modules.payment_gateway.tests import (
     create_payment_profile, create_payment_transaction)
 from trytond.pool import Pool
@@ -28,6 +30,7 @@ def create_write_off():
     Journal = pool.get('account.journal')
     Account = pool.get('account.account')
     Sequence = pool.get('ir.sequence')
+    SequenceType = pool.get('ir.sequence.type')
 
     company, = Company.search([])
     with set_company(company):
@@ -38,8 +41,11 @@ def create_write_off():
                 ('type.expense', '=', True),
                 ])
 
+    sequence_type, = SequenceType.search([
+            ('name', '=', 'Account Journal'),
+            ])
     sequence_journal, = Sequence.search([
-            ('code', '=', 'account.journal'),
+            ('sequence_type', '=', sequence_type.id),
             ])
     journal_write_off = Journal()
     journal_write_off.name = 'Write Off Journal'
@@ -110,12 +116,12 @@ def create_products():
 
             product1, = Product.create([{
                 'template': product_template.id,
-                'code': 'toy-1',
+                'suffix_code': 'toy-1',
                 'cost_price': Decimal('5'),
                 }])
             product2, = Product.create([{
                 'template': product_template.id,
-                'code': 'toy-2',
+                'suffix_code': 'toy-2',
                 'cost_price': Decimal('5'),
                 }])
 
@@ -165,8 +171,9 @@ def create_and_post_invoice(party):
     with Transaction().set_context(company=company.id):
         payment_term = create_payment_term()
         create_products()
-        product1, = Product.search([('code', '=', 'toy-1')])
-        product2, = Product.search([('code', '=', 'toy-2')])
+        Product.search([])[0].code
+        product1, = Product.search([('suffix_code', '=', 'toy-1')])
+        product2, = Product.search([('suffix_code', '=', 'toy-2')])
         invoice, = Invoice.create([{
             'party': party,
             'type': 'out',
@@ -197,7 +204,7 @@ def create_and_post_invoice(party):
     return invoice
 
 
-class InvoicePaymentGatewayTestCase(ModuleTestCase):
+class InvoicePaymentGatewayTestCase(CompanyTestMixin, ModuleTestCase):
     'Test Invoice Payment Gateway module'
     module = 'invoice_payment_gateway'
 
@@ -208,6 +215,7 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
         """
         pool = Pool()
         Company = pool.get('company.company')
+        Invoice = pool.get('account.invoice')
         Wizard = pool.get('account.invoice.pay_using_transaction',
             type='wizard')
 
@@ -219,7 +227,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
 
         company, = Company.search([])
         # Pay invoice using cash transaction
-        with Transaction().set_context(active_id=invoice.id):
+        with Transaction().set_context(
+                active_id=invoice.id,
+                company=company.id):
             pay_wizard = Wizard(Wizard.create()[0])
             defaults = pay_wizard.default_start()
 
@@ -236,10 +246,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
             pay_wizard.start.reference = 'Test paying with cash'
             pay_wizard.start.method = transaction.gateway.method
             pay_wizard.start.transaction_type = defaults['transaction_type']
+            pay_wizard.transition_pay()
 
-            with Transaction().set_context(company=company.id):
-                pay_wizard.transition_pay()
-
+        Invoice.process([invoice])
         self.assertEqual(invoice.state, 'paid')
         self.assertFalse(invoice.amount_to_pay)
 
@@ -251,6 +260,7 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
         pool = Pool()
         Company = pool.get('company.company')
         Date = pool.get('ir.date')
+        Invoice = pool.get('account.invoice')
         Wizard = pool.get(
             'account.invoice.pay_using_transaction', type='wizard')
 
@@ -262,7 +272,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
 
         company, = Company.search([])
         # Pay invoice using card transaction
-        with Transaction().set_context(active_id=invoice.id):
+        with Transaction().set_context(
+                active_id=invoice.id,
+                company=company.id):
             pay_wizard = Wizard(Wizard.create()[0])
             defaults = pay_wizard.default_start()
 
@@ -285,10 +297,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
             pay_wizard.start.csc = '435'
             pay_wizard.start.provider = transaction.gateway.provider
             pay_wizard.start.transaction_type = defaults['transaction_type']
+            pay_wizard.transition_pay()
 
-            with Transaction().set_context(company=company.id):
-                pay_wizard.transition_pay()
-
+        Invoice.process([invoice])
         self.assertEqual(invoice.state, 'paid')
         self.assertFalse(invoice.amount_to_pay)
 
@@ -299,6 +310,7 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
         """
         pool = Pool()
         Company = pool.get('company.company')
+        Invoice = pool.get('account.invoice')
         Wizard = pool.get(
             'account.invoice.pay_using_transaction', type='wizard')
 
@@ -313,7 +325,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
 
         company, = Company.search([])
         # Pay invoice using cash transaction
-        with Transaction().set_context(active_id=invoice.id):
+        with Transaction().set_context(
+                active_id=invoice.id,
+                company=company.id):
             pay_wizard = Wizard(Wizard.create()[0])
             defaults = pay_wizard.default_start()
 
@@ -331,10 +345,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
             pay_wizard.start.method = transaction.gateway.method
             pay_wizard.start.use_existing_card = True
             pay_wizard.start.transaction_type = defaults['transaction_type']
+            pay_wizard.transition_pay()
 
-            with Transaction().set_context(company=company.id):
-                pay_wizard.transition_pay()
-
+        Invoice.process([invoice])
         self.assertEqual(invoice.state, 'paid')
         self.assertFalse(invoice.amount_to_pay)
 
@@ -345,6 +358,7 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
         """
         pool = Pool()
         Company = pool.get('company.company')
+        Invoice = pool.get('account.invoice')
         AccountMove = pool.get('account.move')
         AccountConfiguration = pool.get('account.configuration')
         Wizard = pool.get(
@@ -365,7 +379,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
         self.assertTrue(account_config.write_off)
 
         # Pay invoice using cash transaction
-        with Transaction().set_context(active_id=invoice.id):
+        with Transaction().set_context(
+                active_id=invoice.id,
+                company=company.id):
             pay_wizard = Wizard(Wizard.create()[0])
             defaults = pay_wizard.default_start()
 
@@ -382,10 +398,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
             pay_wizard.start.reference = 'Test paying with cash'
             pay_wizard.start.method = transaction.gateway.method
             pay_wizard.start.transaction_type = defaults['transaction_type']
+            pay_wizard.transition_pay()
 
-            with Transaction().set_context(company=company.id):
-                pay_wizard.transition_pay()
-
+        Invoice.process([invoice])
         self.assertEqual(invoice.state, 'posted')
         self.assertTrue(invoice.amount_to_pay)
 
@@ -393,7 +408,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
         account_config.write_off_threshold = Decimal('0.01')
         account_config.save()
 
-        with Transaction().set_context(active_id=invoice.id):
+        with Transaction().set_context(
+                active_id=invoice.id,
+                company=company.id):
             pay_wizard = Wizard(Wizard.create()[0])
             defaults = pay_wizard.default_start()
 
@@ -410,10 +427,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
             pay_wizard.start.reference = 'Test paying with cash'
             pay_wizard.start.method = transaction.gateway.method
             pay_wizard.start.transaction_type = defaults['transaction_type']
+            pay_wizard.transition_pay()
 
-            with Transaction().set_context(company=company.id):
-                pay_wizard.transition_pay()
-
+        Invoice.process([invoice])
         self.assertEqual(invoice.state, 'paid')
         self.assertFalse(invoice.amount_to_pay)
 
@@ -430,6 +446,7 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
         pool = Pool()
         Company = pool.get('company.company')
         AccountMove = pool.get('account.move')
+        Invoice = pool.get('account.invoice')
         AccountConfiguration = pool.get('account.configuration')
         Wizard = pool.get(
             'account.invoice.pay_using_transaction', type='wizard')
@@ -452,7 +469,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
 
 
         # Pay invoice using cash transaction
-        with Transaction().set_context(active_id=invoice.id):
+        with Transaction().set_context(
+                active_id=invoice.id,
+                company=company.id):
             pay_wizard = Wizard(Wizard.create()[0])
             defaults = pay_wizard.default_start()
 
@@ -469,10 +488,9 @@ class InvoicePaymentGatewayTestCase(ModuleTestCase):
             pay_wizard.start.reference = 'Test paying with cash'
             pay_wizard.start.method = transaction.gateway.method
             pay_wizard.start.transaction_type = defaults['transaction_type']
+            pay_wizard.transition_pay()
 
-            with Transaction().set_context(company=company.id):
-                pay_wizard.transition_pay()
-
+        Invoice.process([invoice])
         self.assertEqual(invoice.state, 'paid')
         self.assertEqual(AccountMove.search_count([]), 2)
 
